@echo off
title Short Games Analyzer Tool (no endgames) V3.2 by Stefan Pohl, www.sp-cc.de
@echo ***************************************************************
@echo ***              Short Games Analyzer Tool V3.2             ***
@echo ***           (C) 2022, Stefan Pohl, www.sp-cc.de           ***
@echo ***************************************************************
@echo ***     This tool uses pgn-extract (C) David J. Barnes      ***
@echo ***************************************************************
@echo ***************************************************************

@echo Enter the name of your games pgn-file (without .pgn ending!) The file must be in the working folder!
@echo off
set /p filename=

set gamebase=%filename%.pgn
CALL :StartTimer

del SGA_no_endgame_full_statistics.txt 2>nul
del SGA_no_endgame_wins_statistics.txt 2>nul
del SGA_no_endgame_draws_statistics.txt 2>nul
del SGA_no_endgame_losses_statistics.txt 2>nul
del short_sac_games_no_endgame.pgn 2>nul 
del shortgames_no_endgame.pgn 2>nul

REM *** Use Norm Pollock tool nameList to find all engine-names in the pgn-file ***
cd ./bin

del worklist.txt 2>nul
del worklist2.txt 2>nul
del worklist_wins.txt 2>nul
del worklist2_wins.txt 2>nul
del worklist_draws.txt 2>nul
del worklist2_draws.txt 2>nul
del worklist_losses.txt 2>nul
del worklist2_losses.txt 2>nul
del sacgames_1_pawns.pgn 2>nul
del sacgames_2_pawns.pgn 2>nul
del sacgames_3_pawns.pgn 2>nul
del sacgames_4_pawns.pgn 2>nul
del sacgames_5_pawns.pgn 2>nul
del sacgames_queensacs.pgn 2>nul

@echo *********************************************************************************************
@echo *** Check file, fix results if necessary, then counting number of engines in the pgn-file
del newsource.pgn 2>nul
pgn-extract --quiet -C -N -V --fixresulttags --plycount ../%gamebase% --output newsource.pgn > NUL

@echo *********************************************************************************************
@echo *** Building output pgn-file: Short wins up to 60 moves, followed by short draws
pgn-extract --quiet --fixresulttags --plycount -bu60 -Tr0-1 -Tr1-0 ../%gamebase% --output temp_output.pgn > NUL
pgn-extract --quiet --fixresulttags --plycount -bu60 -Tr1/2-1/2 ../%gamebase% -atemp_output.pgn  > NUL
@echo *** Material-check: Deleting all games, not ending before endgame is reached
pgn-extract --quiet -zno_endgame temp_output.pgn --output results.pgn >NUL
pgn-extract --quiet -bu60 -cresults.pgn -D -o../shortgames_no_endgame.pgn temp_output.pgn > NUL
del results.pgn 2>nul
del temp_output.pgn 2>nul

nameList newsource.pgn >NUL

REM *** Count number of lines in outname-file (= number of different engines in the source.pgn) ***
set /A numb_engines=0 
for /f %%a in (outname) do set /a numb_engines+=1

REM *** Read the names of all engines and put them in a string-array ***
set /A counter=1
:loop01
set /p engines[%counter%]=<outname
set /A counter=%counter%+1
if %counter% GTR %numb_engines% goto exitloop01
more +1 outname > outnamex 
set /p engines[%counter%]=<outnamex
more +1 outnamex > outname 
set /A counter=%counter%+1
if %counter% GTR %numb_engines% goto exitloop01
goto loop01
:exitloop01
del outname*

@echo *********************************************************************************************
@echo *** Number of engines found in the pgn-file: %numb_engines%
REM *** Start second timer for engine-processing. Needed for estimating the time to finish...
CALL :StartTimer2

REM *** Start of processing all engines, one after another, in a loop ***
set /A engine_counter=1
:loop02

del enginefile 2>nul 
if defined engines[%engine_counter%]  (
call echo "%%engines[%engine_counter%]%%">enginefile
set /p engine=<enginefile
del enginefile 2>nul 
)
@echo *********************************************************************************************
@echo *** Processing engine %engine_counter%/%numb_engines% (%engine%)

fsutil file createnew enginegames.pgn 0 >NUL
fsutil file createnew whitewins.pgn 0 >NUL
fsutil file createnew blackwins.pgn 0 >NUL
fsutil file createnew allwins.pgn 0 >NUL
fsutil file createnew whitelosses.pgn 0 >NUL
fsutil file createnew blacklosses.pgn 0 >NUL
fsutil file createnew alllosses.pgn 0 >NUL
fsutil file createnew alldraws.pgn 0 >NUL
fsutil file createnew no_endgame_games.pgn 0 >NUL
del results_opt1.pgn 2>nul
del results_opt2.pgn 2>nul 
del results_opt3.pgn 2>nul 
del results_opt4.pgn 2>nul 
del results_opt5.pgn 2>nul 
del results_opt9.pgn 2>nul 
del unique_opt1.pgn 2>nul 
del unique_opt2.pgn 2>nul 
del unique_opt3.pgn 2>nul 
del unique_opt4.pgn 2>nul 
del unique_opt5.pgn 2>nul 
del unique_opt9.pgn 2>nul 
del blacksacs.pgn 2>nul
del win60games.pgn 2>nul
del white_eng_games.pgn 2>nul
del white_eng_games_wins.pgn 2>nul
del white_eng_games_draws.pgn 2>nul
del white_eng_games_losses.pgn 2>nul
del black_eng_games.pgn 2>nul
del black_eng_games_wins.pgn 2>nul
del black_eng_games_draws.pgn 2>nul
del black_eng_games_losses.pgn 2>nul
fsutil file createnew results_opt1.pgn 0 >NUL
fsutil file createnew results_opt2.pgn 0 >NUL
fsutil file createnew results_opt3.pgn 0 >NUL
fsutil file createnew results_opt4.pgn 0 >NUL
fsutil file createnew results_opt5.pgn 0 >NUL
fsutil file createnew results_opt9.pgn 0 >NUL
fsutil file createnew whitewins.pgn 0 >NUL
fsutil file createnew blackwins.pgn 0 >NUL

@echo *********************************************************************************************
@echo *** Filter all games played by the engine out of pgn-file
pgn-extract --quiet -Tp%engine% newsource.pgn --output enginegames.pgn > NUL

@echo *********************************************************************************************
@echo|set /p="*** Games by %engine%: "

REM *** Filter won games by the engine ***
pgn-extract --quiet -Tr1-0 -Tw%engine% enginegames.pgn --output whitewins.pgn > NUL
pgn-extract --quiet -Tr0-1 -Tb%engine% enginegames.pgn --output blackwins.pgn > NUL
copy whitewins.pgn+blackwins.pgn allwins.pgn > NUL

REM *** Count number of won games by the engine ***
CALL :countgames allwins.pgn
set /A numb_wins=%c_numb_pgn%
@echo|set /p="%numb_wins% wins "

REM *** Filter won games by the engine ***
pgn-extract --quiet -Tr1/2-1/2 enginegames.pgn --output alldraws.pgn > NUL

REM *** Count number of won games by the engine ***
CALL :countgames alldraws.pgn
set /A numb_draws=%c_numb_pgn%
@echo|set /p=" / %numb_draws% draws "

REM *** Filter lost games by the engine ***
pgn-extract --quiet -Tr0-1 -Tw%engine% enginegames.pgn --output whitelosses.pgn > NUL
pgn-extract --quiet -Tr1-0 -Tb%engine% enginegames.pgn --output blacklosses.pgn > NUL
copy whitelosses.pgn+blacklosses.pgn alllosses.pgn > NUL

REM *** Count number of lost games by the engine ***
CALL :countgames alllosses.pgn
set /A numb_losses=%c_numb_pgn%
@echo|set /p=" / %numb_losses% losses "

REM *** Add wins,draws,losses to number of total played games
set /A numb_allgames=%numb_wins%+%numb_draws%+%numb_losses%
@echo  = %numb_allgames% total

@echo *********************************************************************************************
@echo *** Calculating overall game-length values
REM *** Build average game length numbers (all/win/draw/loss) of the engine
set /A length_all=0
set /A length_wins=0
set /A length_draws=0
set /A length_loss=0
set /A length_all_w=0
set /A length_wins_w=0
set /A length_draws_w=0
set /A length_loss_w=0
set /A length_all_b=0
set /A length_wins_b=0
set /A length_draws_b=0
set /A length_loss_b=0
CALL :moveaverage enginegames.pgn
set /A length_all=%ma_moveaverage%
CALL :moveaverage allwins.pgn
set /A length_wins=%ma_moveaverage%
CALL :moveaverage alldraws.pgn
set /A length_draws=%ma_moveaverage%
CALL :moveaverage alllosses.pgn
set /A length_loss=%ma_moveaverage%
pgn-extract --quiet -Tw%engine% enginegames.pgn --output white_eng_games.pgn > NUL
pgn-extract --quiet -Tb%engine% enginegames.pgn --output black_eng_games.pgn > NUL

pgn-extract --quiet -Tr1-0 white_eng_games.pgn --output white_eng_games_wins.pgn > NUL
pgn-extract --quiet -Tr1/2-1/2 white_eng_games.pgn --output white_eng_games_draws.pgn > NUL
pgn-extract --quiet -Tr0-1 white_eng_games.pgn --output white_eng_games_losses.pgn > NUL
CALL :moveaverage white_eng_games.pgn
set /A length_all_w=%ma_moveaverage%
CALL :moveaverage white_eng_games_wins.pgn
set /A length_wins_w=%ma_moveaverage%
CALL :moveaverage white_eng_games_draws.pgn
set /A length_draws_w=%ma_moveaverage%
CALL :moveaverage white_eng_games_losses.pgn
set /A length_loss_w=%ma_moveaverage%

pgn-extract --quiet -Tr0-1 black_eng_games.pgn --output black_eng_games_wins.pgn > NUL
pgn-extract --quiet -Tr1/2-1/2 black_eng_games.pgn --output black_eng_games_draws.pgn > NUL
pgn-extract --quiet -Tr1-0 black_eng_games.pgn --output black_eng_games_losses.pgn > NUL
CALL :moveaverage black_eng_games.pgn
set /A length_all_b=%ma_moveaverage%
CALL :moveaverage black_eng_games_wins.pgn
set /A length_wins_b=%ma_moveaverage%
CALL :moveaverage black_eng_games_draws.pgn
set /A length_draws_b=%ma_moveaverage%
CALL :moveaverage black_eng_games_losses.pgn
set /A length_loss_b=%ma_moveaverage%



REM *** Calculate the overall score of the engine ***
set /A no_ten=%numb_allgames%*10
set /A eng_sc=((%numb_wins%*10)+(%numb_draws%*5))
CALL :percent %no_ten% %eng_sc%
set engine_score=%percent%

REM *** Calculate the draw-rate of the engine ***
CALL :percent %numb_allgames% %numb_draws%
set engine_drawrate=%percent%

REM *** delete all short games, which ended in an endgame
REM *** Could be switched off, if user dont want it, just jump over here
REM *** goto jumpover_endgame_check

@echo *********************************************************************************************
@echo *** Material-check: Deleting all games, not ending before endgame is reached
pgn-extract --quiet -bu60 -zno_endgame allwins.pgn --output results.pgn >NUL
pgn-extract --quiet -bu60 -cresults.pgn -D -ono_endgame_games.pgn allwins.pgn > NUL
del allwins.pgn 2>nul
copy no_endgame_games.pgn allwins.pgn >NUL
fsutil file createnew no_endgame_games.pgn 0 >NUL
pgn-extract --quiet -bu60 -zno_endgame alldraws.pgn --output results.pgn >NUL
pgn-extract --quiet -bu60 -cresults.pgn -D -ono_endgame_games.pgn alldraws.pgn > NUL
del alldraws.pgn 2>nul
copy no_endgame_games.pgn alldraws.pgn >NUL
fsutil file createnew no_endgame_games.pgn 0 >NUL
pgn-extract --quiet -bu60 -zno_endgame alllosses.pgn --output results.pgn >NUL
pgn-extract --quiet -bu60 -cresults.pgn -D -ono_endgame_games.pgn alllosses.pgn > NUL
del alllosses.pgn 2>nul
copy no_endgame_games.pgn alllosses.pgn >NUL
del no_endgame_games.pgn 2>nul
:jumpover_endgame_check


@echo *********************************************************************************************
@echo|set /p="*** Searching for short wins..."

del temp.pgn 2>nul
del win60games.pgn 2>nul
pgn-extract --quiet -bu60 allwins.pgn --output temp.pgn > NUL
copy temp.pgn win60games.pgn > NUL

REM *** Count number of wins of the engine, not longer than 30 moves ***
pgn-extract --quiet -bu30 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortwins=%c_numb_pgn%
set /A won_30_mvs=%numb_shortwins%
CALL :formatnumb %numb_shortwins%
set list_wins_30mvs=%formatted%
CALL :percent %numb_wins% %numb_shortwins%
set list_wins_30mvs_pcnt=%percent%

REM *** Count number of wins of the engine, not longer than 35 moves ***
pgn-extract --quiet -bu35 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortwins=%c_numb_pgn%
set /A won_35_mvs=%numb_shortwins%
set /A numb_shortwins=%numb_shortwins%-%won_30_mvs%
CALL :formatnumb %numb_shortwins%
set list_wins_35mvs=%formatted%
CALL :percent %numb_wins% %numb_shortwins%
set list_wins_35mvs_pcnt=%percent%

REM *** Count number of wins of the engine, not longer than 40 moves ***
pgn-extract --quiet -bu40 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortwins=%c_numb_pgn%
set /A won_40_mvs=%numb_shortwins%
set /A numb_shortwins=%numb_shortwins%-%won_35_mvs%
CALL :formatnumb %numb_shortwins%
set list_wins_40mvs=%formatted%
CALL :percent %numb_wins% %numb_shortwins%
set list_wins_40mvs_pcnt=%percent%

REM *** Count number of wins of the engine, not longer than 45 moves ***
pgn-extract --quiet -bu45 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortwins=%c_numb_pgn%
set /A won_45_mvs=%numb_shortwins%
set /A numb_shortwins=%numb_shortwins%-%won_40_mvs%
CALL :formatnumb %numb_shortwins%
set list_wins_45mvs=%formatted%
CALL :percent %numb_wins% %numb_shortwins%
set list_wins_45mvs_pcnt=%percent%

REM *** Count number of wins of the engine, not longer than 50 moves ***
pgn-extract --quiet -bu50 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortwins=%c_numb_pgn%
set /A won_50_mvs=%numb_shortwins%
set /A numb_shortwins=%numb_shortwins%-%won_45_mvs%
CALL :formatnumb %numb_shortwins%
set list_wins_50mvs=%formatted%
CALL :percent %numb_wins% %numb_shortwins%
set list_wins_50mvs_pcnt=%percent%

REM *** Count number of wins of the engine, not longer than 55 moves ***
pgn-extract --quiet -bu55 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortwins=%c_numb_pgn%
set /A won_55_mvs=%numb_shortwins%
set /A numb_shortwins=%numb_shortwins%-%won_50_mvs%
CALL :formatnumb %numb_shortwins%
set list_wins_55mvs=%formatted%
CALL :percent %numb_wins% %numb_shortwins%
set list_wins_55mvs_pcnt=%percent%

REM *** Count number of wins of the engine, not longer than 60 moves ***
CALL :countgames temp.pgn
set /A numb_shortwins=%c_numb_pgn%
set /A won_60_mvs=%numb_shortwins%
REM *** For the ratinglist-output, build the percent-number of all short wins before endgame
CALL :formatnumb %numb_shortwins%
set list_all_wins=%formatted%
CALL :percent %numb_wins% %numb_shortwins%
set percent_all_shortwins=%percent%
set /A points=50000+%percentx100%
set /A points_wins=10000+%percentx100%
set /A numb_shortwins=%numb_shortwins%-%won_55_mvs%
CALL :formatnumb %numb_shortwins%
set list_wins_60mvs=%formatted%
CALL :percent %numb_wins% %numb_shortwins%
set list_wins_60mvs_pcnt=%percent%

@echo|set /p="Searching for short draws..."

del temp.pgn 2>nul
pgn-extract --quiet -bu60 alldraws.pgn --output temp.pgn > NUL

REM *** Count number of draws of the engine, not longer than 30 moves ***
pgn-extract --quiet -bu30 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortdraws=%c_numb_pgn%
set /A draw_30_mvs=%numb_shortdraws%
CALL :formatnumb %numb_shortdraws%
set list_draws_30mvs=%formatted%
CALL :percent %numb_draws% %numb_shortdraws%
set list_draws_30mvs_pcnt=%percent%

REM *** Count number of draws of the engine, not longer than 35 moves ***
pgn-extract --quiet -bu35 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortdraws=%c_numb_pgn%
set /A draw_35_mvs=%numb_shortdraws%
set /A numb_shortdraws=%numb_shortdraws%-%draw_30_mvs%
CALL :formatnumb %numb_shortdraws%
set list_draws_35mvs=%formatted%
CALL :percent %numb_draws% %numb_shortdraws%
set list_draws_35mvs_pcnt=%percent%

REM *** Count number of draws of the engine, not longer than 40 moves ***
pgn-extract --quiet -bu40 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortdraws=%c_numb_pgn%
set /A draw_40_mvs=%numb_shortdraws%
set /A numb_shortdraws=%numb_shortdraws%-%draw_35_mvs%
CALL :formatnumb %numb_shortdraws%
set list_draws_40mvs=%formatted%
CALL :percent %numb_draws% %numb_shortdraws%
set list_draws_40mvs_pcnt=%percent%

REM *** Count number of draws of the engine, not longer than 45 moves ***
pgn-extract --quiet -bu45 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortdraws=%c_numb_pgn%
set /A draw_45_mvs=%numb_shortdraws%
set /A numb_shortdraws=%numb_shortdraws%-%draw_40_mvs%
CALL :formatnumb %numb_shortdraws%
set list_draws_45mvs=%formatted%
CALL :percent %numb_draws% %numb_shortdraws%
set list_draws_45mvs_pcnt=%percent%

REM *** Count number of draws of the engine, not longer than 50 moves ***
pgn-extract --quiet -bu50 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortdraws=%c_numb_pgn%
set /A draw_50_mvs=%numb_shortdraws%
set /A numb_shortdraws=%numb_shortdraws%-%draw_45_mvs%
CALL :formatnumb %numb_shortdraws%
set list_draws_50mvs=%formatted%
CALL :percent %numb_draws% %numb_shortdraws%
set list_draws_50mvs_pcnt=%percent%

REM *** Count number of draws of the engine, not longer than 55 moves ***
pgn-extract --quiet -bu55 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortdraws=%c_numb_pgn%
set /A draw_55_mvs=%numb_shortdraws%
set /A numb_shortdraws=%numb_shortdraws%-%draw_50_mvs%
CALL :formatnumb %numb_shortdraws%
set list_draws_55mvs=%formatted%
CALL :percent %numb_draws% %numb_shortdraws%
set list_draws_55mvs_pcnt=%percent%

REM *** Count number of draws of the engine, not longer than 60 moves ***
CALL :countgames temp.pgn
set /A numb_shortdraws=%c_numb_pgn%
set /A draw_60_mvs=%numb_shortdraws%
REM *** For the ratinglist-output, build the percent-number of all short draws
CALL :formatnumb %numb_shortdraws%
set list_all_draws=%formatted%
CALL :percent %numb_draws% %numb_shortdraws%
set percent_all_shortdraws=%percent%
set /A points-=%percentx100%
set /A points_draws=10000+%percentx100%
set /A numb_shortdraws=%numb_shortdraws%-%draw_55_mvs%
CALL :formatnumb %numb_shortdraws%
set list_draws_60mvs=%formatted%
CALL :percent %numb_draws% %numb_shortdraws%
set list_draws_60mvs_pcnt=%percent%

@echo|set /p="Searching for short losses..."

del temp.pgn 2>nul
pgn-extract --quiet -bu60 alllosses.pgn --output temp.pgn > NUL

REM *** Count number of losses of the engine, not longer than 30 moves ***
pgn-extract --quiet -bu30 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortlosses=%c_numb_pgn%
set /A loss_30_mvs=%numb_shortlosses%
CALL :formatnumb %numb_shortlosses%
set list_losses_30mvs=%formatted%
CALL :percent %numb_losses% %numb_shortlosses%
set list_losses_30mvs_pcnt=%percent%

REM *** Count number of losses of the engine, not longer than 35 moves ***
pgn-extract --quiet -bu35 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortlosses=%c_numb_pgn%
set /A loss_35_mvs=%numb_shortlosses%
set /A numb_shortlosses=%numb_shortlosses%-%loss_30_mvs%
CALL :formatnumb %numb_shortlosses%
set list_losses_35mvs=%formatted%
CALL :percent %numb_losses% %numb_shortlosses%
set list_losses_35mvs_pcnt=%percent%

REM *** Count number of losses of the engine, not longer than 40 moves ***
pgn-extract --quiet -bu40 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortlosses=%c_numb_pgn%
set /A loss_40_mvs=%numb_shortlosses%
set /A numb_shortlosses=%numb_shortlosses%-%loss_35_mvs%
CALL :formatnumb %numb_shortlosses%
set list_losses_40mvs=%formatted%
CALL :percent %numb_losses% %numb_shortlosses%
set list_losses_40mvs_pcnt=%percent%

REM *** Count number of losses of the engine, not longer than 45 moves ***
pgn-extract --quiet -bu45 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortlosses=%c_numb_pgn%
set /A loss_45_mvs=%numb_shortlosses%
set /A numb_shortlosses=%numb_shortlosses%-%loss_40_mvs%
CALL :formatnumb %numb_shortlosses%
set list_losses_45mvs=%formatted%
CALL :percent %numb_losses% %numb_shortlosses%
set list_losses_45mvs_pcnt=%percent%

REM *** Count number of losses of the engine, not longer than 50 moves ***
pgn-extract --quiet -bu50 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortlosses=%c_numb_pgn%
set /A loss_50_mvs=%numb_shortlosses%
set /A numb_shortlosses=%numb_shortlosses%-%loss_45_mvs%
CALL :formatnumb %numb_shortlosses%
set list_losses_50mvs=%formatted%
CALL :percent %numb_losses% %numb_shortlosses%
set list_losses_50mvs_pcnt=%percent%

REM *** Count number of losses of the engine, not longer than 55 moves ***
pgn-extract --quiet -bu55 temp.pgn --output results.pgn > NUL
CALL :countgames results.pgn
set /A numb_shortlosses=%c_numb_pgn%
set /A loss_55_mvs=%numb_shortlosses%
set /A numb_shortlosses=%numb_shortlosses%-%loss_50_mvs%
CALL :formatnumb %numb_shortlosses%
set list_losses_55mvs=%formatted%
CALL :percent %numb_losses% %numb_shortlosses%
set list_losses_55mvs_pcnt=%percent%

REM *** Count number of losses of the engine, not longer than 60 moves ***
CALL :countgames temp.pgn
set /A numb_shortlosses=%c_numb_pgn%
set /A loss_60_mvs=%numb_shortlosses%
REM *** For the ratinglist-output, build the percent-number of all short losses
CALL :formatnumb %numb_shortlosses%
set list_all_losses=%formatted%
CALL :percent %numb_losses% %numb_shortlosses%
set percent_all_shortlosses=%percent%
set /A points-=%percentx100%
set /A points_losses=10000+%percentx100%
set /A numb_shortlosses=%numb_shortlosses%-%loss_55_mvs%
CALL :formatnumb %numb_shortlosses%
set list_losses_60mvs=%formatted%
CALL :percent %numb_losses% %numb_shortlosses%
set list_losses_60mvs_pcnt=%percent%
@echo done
@echo *********************************************************************************************
del temp.pgn 2>nul

REM *** Search for sacrifices in the short wins of the engine
fsutil file createnew whitewins.pgn 0 >NUL
fsutil file createnew blackwins.pgn 0 >NUL
fsutil file createnew blacksacs.pgn 0 >NUL
pgn-extract --quiet -Tr1-0 win60games.pgn --output whitewins.pgn > NUL
pgn-extract --quiet -Tr0-1 win60games.pgn --output blackwins.pgn > NUL

@echo|set /p="*** Searching for sacrifices in the short wins (0-60 moves)..."

pgn-extract --quiet -y1_pawnsac_white whitewins.pgn --output results_opt1.pgn >NUL
del whitewins.pgn 2>nul
copy results_opt1.pgn whitewins.pgn > NUL
pgn-extract --quiet -y1_pawnsac_black blackwins.pgn --output blacksacs.pgn >NUL
REM *** Merge all found games in one single file ***
pgn-extract --quiet -aresults_opt1.pgn blacksacs.pgn >NUL
del blackwins.pgn 2>nul
copy blacksacs.pgn blackwins.pgn > NUL

pgn-extract --quiet -y2_pawnsac_white whitewins.pgn --output results_opt2.pgn >NUL
pgn-extract --quiet -y2_pawnsac_black blackwins.pgn --output blacksacs.pgn >NUL
del whitewins.pgn 2>nul
del blackwins.pgn 2>nul
copy results_opt2.pgn whitewins.pgn > NUL
copy blacksacs.pgn blackwins.pgn > NUL
REM *** Merge all found games in one single file ***
pgn-extract --quiet -aresults_opt2.pgn blacksacs.pgn >NUL
fsutil file createnew blacksacs.pgn 0 >NUL

pgn-extract --quiet -y3_pawnsac_white whitewins.pgn --output results_opt3.pgn >NUL
pgn-extract --quiet -y3_pawnsac_black blackwins.pgn --output blacksacs.pgn >NUL
del whitewins.pgn 2>nul
del blackwins.pgn 2>nul
copy results_opt3.pgn whitewins.pgn > NUL
copy blacksacs.pgn blackwins.pgn > NUL
REM *** Merge all found games in one single file ***
pgn-extract --quiet -aresults_opt3.pgn blacksacs.pgn >NUL
fsutil file createnew blacksacs.pgn 0 >NUL

pgn-extract --quiet -y4_pawnsac_white whitewins.pgn --output results_opt4.pgn >NUL
pgn-extract --quiet -y4_pawnsac_black blackwins.pgn --output blacksacs.pgn >NUL
del whitewins.pgn 2>nul
del blackwins.pgn 2>nul
copy results_opt4.pgn whitewins.pgn > NUL
copy blacksacs.pgn blackwins.pgn > NUL
REM *** Merge all found games in one single file ***
pgn-extract --quiet -aresults_opt4.pgn blacksacs.pgn >NUL
fsutil file createnew blacksacs.pgn 0 >NUL

pgn-extract --quiet -y5_pawnsac_white whitewins.pgn --output results_opt5.pgn >NUL
pgn-extract --quiet -y5_pawnsac_black blackwins.pgn --output blacksacs.pgn >NUL
del whitewins.pgn 2>nul
del blackwins.pgn 2>nul
copy results_opt5.pgn whitewins.pgn > NUL
copy blacksacs.pgn blackwins.pgn > NUL
REM *** Merge all found games in one single file ***
pgn-extract --quiet -aresults_opt5.pgn blacksacs.pgn >NUL

pgn-extract --quiet -yqueensac_white whitewins.pgn --output results_opt9.pgn >NUL
pgn-extract --quiet -yqueensac_black blackwins.pgn --output blacksacs.pgn >NUL
REM *** Merge all found games in one single file ***
pgn-extract --quiet -aresults_opt9.pgn blacksacs.pgn >NUL

REM *** Delete games in the gamebases with lower sacs, which already occur in higher sacs files...***
fsutil file createnew unique_opt1.pgn 0 >NUL
fsutil file createnew unique_opt2.pgn 0 >NUL
fsutil file createnew unique_opt3.pgn 0 >NUL
fsutil file createnew unique_opt4.pgn 0 >NUL
fsutil file createnew unique_opt5.pgn 0 >NUL
fsutil file createnew unique_opt9.pgn 0 >NUL

pgn-extract --quiet -D -ounique_opt9.pgn results_opt9.pgn >NUL
pgn-extract --quiet -cresults_opt9.pgn -D -ounique_opt5.pgn results_opt5.pgn > NUL
pgn-extract --quiet -cresults_opt5.pgn -D -ounique_opt4.pgn results_opt4.pgn > NUL
pgn-extract --quiet -cresults_opt4.pgn -D -ounique_opt3.pgn results_opt3.pgn > NUL
pgn-extract --quiet -cresults_opt3.pgn -D -ounique_opt2.pgn results_opt2.pgn > NUL
pgn-extract --quiet -cresults_opt2.pgn -D -ounique_opt1.pgn results_opt1.pgn > NUL

REM *** Add sac games to the output pgn-files ***
pgn-extract --quiet -asacgames_1_pawns.pgn unique_opt1.pgn >NUL
pgn-extract --quiet -asacgames_2_pawns.pgn unique_opt2.pgn >NUL
pgn-extract --quiet -asacgames_3_pawns.pgn unique_opt3.pgn >NUL
pgn-extract --quiet -asacgames_4_pawns.pgn unique_opt4.pgn >NUL
pgn-extract --quiet -asacgames_5_pawns.pgn unique_opt5.pgn >NUL
pgn-extract --quiet -asacgames_queensacs.pgn unique_opt9.pgn >NUL

REM *** Count the number of games in the result bases...***
CALL :countgames unique_opt9.pgn
set /A numb_sac9=%c_numb_pgn%
CALL :countgames unique_opt5.pgn
set /A numb_sac5=%c_numb_pgn%
CALL :countgames unique_opt4.pgn
set /A numb_sac4=%c_numb_pgn%
CALL :countgames unique_opt3.pgn
set /A numb_sac3=%c_numb_pgn%
CALL :countgames unique_opt2.pgn
set /A numb_sac2=%c_numb_pgn%
CALL :countgames unique_opt1.pgn
set /A numb_sac1=%c_numb_pgn%

REM *** Count the number off all sacs found (add all 6 sac-numbers) ***
set /A numb_sumsac=%numb_sac1%+%numb_sac2%+%numb_sac3%+%numb_sac4%+%numb_sac5%+%numb_sac9%

REM *** Build percent number of sacs
CALL :percent %numb_wins% %numb_sac9%
set pcnt_sac9=%percent%
CALL :percent %numb_wins% %numb_sac5%
set pcnt_sac5=%percent%
CALL :percent %numb_wins% %numb_sac4%
set pcnt_sac4=%percent%
CALL :percent %numb_wins% %numb_sac3%
set pcnt_sac3=%percent%
CALL :percent %numb_wins% %numb_sac2%
set pcnt_sac2=%percent%
CALL :percent %numb_wins% %numb_sac1%
set pcnt_sac1=%percent%
CALL :percent %numb_wins% %numb_sumsac%
set pcnt_sumsac=%percent%

REM *** formatting gamenumbers
CALL :formatnumb %numb_sumsac%
set numb_sumsac=%formatted%
CALL :formatnumb %numb_sac9%
set numb_sac9=%formatted%
CALL :formatnumb %numb_sac5%
set numb_sac5=%formatted%
CALL :formatnumb %numb_sac4%
set numb_sac4=%formatted%
CALL :formatnumb %numb_sac3%
set numb_sac3=%formatted%
CALL :formatnumb %numb_sac2%
set numb_sac2=%formatted%
CALL :formatnumb %numb_sac1%
set numb_sac1=%formatted%

@echo done
@echo *********************************************************************************************


REM *** Build codenumber for later sorting the engines by their results
set /A enginenumber=%engine_counter%
if %enginenumber% LEQ 9 (
set enginenumber=00%enginenumber%
goto formatting)
if %enginenumber% LEQ 99 (
set enginenumber=0%enginenumber%
goto formatting)
if %enginenumber% LEQ 999 (
set enginenumber=%enginenumber%
goto formatting)
:formatting

set codenumber=%points%%enginenumber%
@echo %codenumber%28 ************************************************************************************************>>worklist.txt
@echo %codenumber%27 %engine%  All games: %numb_allgames% (%numb_wins% wins / %numb_draws% draws / %numb_losses% losses)>>worklist.txt
@echo %codenumber%26 *** Overall score: %engine_score%     Overall draw-rate: %engine_drawrate%>>worklist.txt
@echo %codenumber%25 *** Average game length: All: %length_all% moves (wins: %length_wins% moves / draws: %length_draws% moves / losses: %length_loss% moves)>>worklist.txt 
@echo %codenumber%24 *** Avg. eng play white: All: %length_all_w% moves (wins: %length_wins_w% moves / draws: %length_draws_w% moves / losses: %length_loss_w% moves)>>worklist.txt 
@echo %codenumber%23 *** Avg. eng play black: All: %length_all_b% moves (wins: %length_wins_b% moves / draws: %length_draws_b% moves / losses: %length_loss_b% moves)>>worklist.txt 
@echo %codenumber%22 ************************************************************************************************>>worklist.txt
@echo %codenumber%21 *** all short wins   wins0-30   wins31-35  wins36-40  wins41-45  wins46-50  wins51-55  wins56-60>>worklist.txt
@echo %codenumber%20 *** -------------------------------------------------------------------------------------------->>worklist.txt
@echo %codenumber%19 ***    [%percent_all_shortwins%] =    [%list_wins_30mvs_pcnt%  +  %list_wins_35mvs_pcnt%  +  %list_wins_40mvs_pcnt%  +  %list_wins_45mvs_pcnt%  +  %list_wins_50mvs_pcnt%  +  %list_wins_55mvs_pcnt%  +  %list_wins_60mvs_pcnt%]>>worklist.txt
@echo %codenumber%18 ***    [%list_all_wins%] =    [%list_wins_30mvs%  +  %list_wins_35mvs%  +  %list_wins_40mvs%  +  %list_wins_45mvs%  +  %list_wins_50mvs%  +  %list_wins_55mvs%  +  %list_wins_60mvs%]>>worklist.txt
@echo %codenumber%17 *** -------------------------------------------------------------------------------------------->>worklist.txt
@echo %codenumber%16 *** all short sacs  sacs queen   sacs 5+p   sacs 4p    sacs 3p    sacs 2p    sacs 1p(=pawn-unit) >>worklist.txt
@echo %codenumber%15 *** -------------------------------------------------------------------------------------------->>worklist.txt
@echo %codenumber%14 ***    [%pcnt_sumsac%] =    [%pcnt_sac9%  +  %pcnt_sac5%  +  %pcnt_sac4%  +  %pcnt_sac3%  +  %pcnt_sac2%  +  %pcnt_sac1%]>>worklist.txt
@echo %codenumber%13 ***    [%numb_sumsac%] =    [%numb_sac9%  +  %numb_sac5%  +  %numb_sac4%  +  %numb_sac3%  +  %numb_sac2%  +  %numb_sac1%]>>worklist.txt
@echo %codenumber%12 ************************************************************************************************>>worklist.txt
@echo %codenumber%11 *** all short draws  draw0-30   draw31-35  draw36-40  draw41-45  draw46-50  draw51-55  draw56-60>>worklist.txt
@echo %codenumber%10 *** -------------------------------------------------------------------------------------------->>worklist.txt
@echo %codenumber%09 ***    [%percent_all_shortdraws%] =    [%list_draws_30mvs_pcnt%  +  %list_draws_35mvs_pcnt%  +  %list_draws_40mvs_pcnt%  +  %list_draws_45mvs_pcnt%  +  %list_draws_50mvs_pcnt%  +  %list_draws_55mvs_pcnt%  +  %list_draws_60mvs_pcnt%]>>worklist.txt
@echo %codenumber%08 ***    [%list_all_draws%] =    [%list_draws_30mvs%  +  %list_draws_35mvs%  +  %list_draws_40mvs%  +  %list_draws_45mvs%  +  %list_draws_50mvs%  +  %list_draws_55mvs%  +  %list_draws_60mvs%]>>worklist.txt
@echo %codenumber%07 ************************************************************************************************>>worklist.txt
@echo %codenumber%06 *** all short losses loss0-30   loss31-35  loss36-40  loss41-45  loss46-50  loss51-55  loss56-60>>worklist.txt
@echo %codenumber%05 *** -------------------------------------------------------------------------------------------->>worklist.txt
@echo %codenumber%04 ***    [%percent_all_shortlosses%] =    [%list_losses_30mvs_pcnt%  +  %list_losses_35mvs_pcnt%  +  %list_losses_40mvs_pcnt%  +  %list_losses_45mvs_pcnt%  +  %list_losses_50mvs_pcnt%  +  %list_losses_55mvs_pcnt%  +  %list_losses_60mvs_pcnt%]>>worklist.txt
@echo %codenumber%03 ***    [%list_all_losses%] =    [%list_losses_30mvs%  +  %list_losses_35mvs%  +  %list_losses_40mvs%  +  %list_losses_45mvs%  +  %list_losses_50mvs%  +  %list_losses_55mvs%  +  %list_losses_60mvs%]>>worklist.txt
@echo %codenumber%02 ************************************************************************************************>>worklist.txt
@echo %codenumber%01 XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX>>worklist.txt

set codenumber=%points_wins%%enginenumber%
@echo %codenumber%18 ************************************************************************************************>>worklist_wins.txt
@echo %codenumber%17 %engine%  All games: %numb_allgames% (%numb_wins% wins / %numb_draws% draws / %numb_losses% losses)>>worklist_wins.txt
@echo %codenumber%16 *** Overall score: %engine_score%     Overall draw-rate: %engine_drawrate% >>worklist_wins.txt
@echo %codenumber%15 *** Average game length: All: %length_all% moves (wins: %length_wins% moves / draws: %length_draws% moves / losses: %length_loss% moves)>>worklist_wins.txt 
@echo %codenumber%14 *** Avg. eng play white: All: %length_all_w% moves (wins: %length_wins_w% moves / draws: %length_draws_w% moves / losses: %length_loss_w% moves)>>worklist_wins.txt 
@echo %codenumber%13 *** Avg. eng play black: All: %length_all_b% moves (wins: %length_wins_b% moves / draws: %length_draws_b% moves / losses: %length_loss_b% moves)>>worklist_wins.txt 
@echo %codenumber%12 ************************************************************************************************>>worklist_wins.txt
@echo %codenumber%11 *** all short wins   wins0-30   wins31-35  wins36-40  wins41-45  wins46-50  wins51-55  wins56-60>>worklist_wins.txt
@echo %codenumber%10 *** -------------------------------------------------------------------------------------------->>worklist_wins.txt
@echo %codenumber%09 ***    [%percent_all_shortwins%] =    [%list_wins_30mvs_pcnt%  +  %list_wins_35mvs_pcnt%  +  %list_wins_40mvs_pcnt%  +  %list_wins_45mvs_pcnt%  +  %list_wins_50mvs_pcnt%  +  %list_wins_55mvs_pcnt%  +  %list_wins_60mvs_pcnt%]>>worklist_wins.txt
@echo %codenumber%08 ***    [%list_all_wins%] =    [%list_wins_30mvs%  +  %list_wins_35mvs%  +  %list_wins_40mvs%  +  %list_wins_45mvs%  +  %list_wins_50mvs%  +  %list_wins_55mvs%  +  %list_wins_60mvs%]>>worklist_wins.txt
@echo %codenumber%07 *** -------------------------------------------------------------------------------------------->>worklist_wins.txt
@echo %codenumber%06 *** all short sacs  sacs queen   sacs 5+p   sacs 4p    sacs 3p    sacs 2p    sacs 1p(=pawn-unit) >>worklist_wins.txt
@echo %codenumber%05 *** -------------------------------------------------------------------------------------------->>worklist_wins.txt
@echo %codenumber%04 ***    [%pcnt_sumsac%] =    [%pcnt_sac9%  +  %pcnt_sac5%  +  %pcnt_sac4%  +  %pcnt_sac3%  +  %pcnt_sac2%  +  %pcnt_sac1%]>>worklist_wins.txt
@echo %codenumber%03 ***    [%numb_sumsac%] =    [%numb_sac9%  +  %numb_sac5%  +  %numb_sac4%  +  %numb_sac3%  +  %numb_sac2%  +  %numb_sac1%]>>worklist_wins.txt
@echo %codenumber%02 ************************************************************************************************>>worklist_wins.txt
@echo %codenumber%01 XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX>>worklist_wins.txt

set codenumber=%points_draws%%enginenumber%
@echo %codenumber%01 ************************************************************************************************>>worklist_draws.txt
@echo %codenumber%02 %engine%  All games: %numb_allgames% (%numb_wins% wins / %numb_draws% draws / %numb_losses% losses)>>worklist_draws.txt
@echo %codenumber%03 *** Overall score: %engine_score%     Overall draw-rate: %engine_drawrate% >>worklist_draws.txt
@echo %codenumber%04 *** Average game length: All: %length_all% moves (wins: %length_wins% moves / draws: %length_draws% moves / losses: %length_loss% moves)>>worklist_draws.txt 
@echo %codenumber%05 *** Avg. eng play white: All: %length_all_w% moves (wins: %length_wins_w% moves / draws: %length_draws_w% moves / losses: %length_loss_w% moves)>>worklist_draws.txt 
@echo %codenumber%06 *** Avg. eng play black: All: %length_all_b% moves (wins: %length_wins_b% moves / draws: %length_draws_b% moves / losses: %length_loss_b% moves)>>worklist_draws.txt 
@echo %codenumber%07 ************************************************************************************************>>worklist_draws.txt
@echo %codenumber%08 *** all short draws  draw0-30   draw31-35  draw36-40  draw41-45  draw46-50  draw51-55  draw56-60>>worklist_draws.txt
@echo %codenumber%09 *** -------------------------------------------------------------------------------------------->>worklist_draws.txt
@echo %codenumber%10 ***    [%percent_all_shortdraws%] =    [%list_draws_30mvs_pcnt%  +  %list_draws_35mvs_pcnt%  +  %list_draws_40mvs_pcnt%  +  %list_draws_45mvs_pcnt%  +  %list_draws_50mvs_pcnt%  +  %list_draws_55mvs_pcnt%  +  %list_draws_60mvs_pcnt%]>>worklist_draws.txt
@echo %codenumber%11 ***    [%list_all_draws%] =    [%list_draws_30mvs%  +  %list_draws_35mvs%  +  %list_draws_40mvs%  +  %list_draws_45mvs%  +  %list_draws_50mvs%  +  %list_draws_55mvs%  +  %list_draws_60mvs%]>>worklist_draws.txt
@echo %codenumber%12 ************************************************************************************************>>worklist_draws.txt
@echo %codenumber%13 XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX>>worklist_draws.txt

set codenumber=%points_losses%%enginenumber%
@echo %codenumber%01 ************************************************************************************************>>worklist_losses.txt
@echo %codenumber%02 %engine%  All games: %numb_allgames% (%numb_wins% wins / %numb_draws% draws / %numb_losses% losses)>>worklist_losses.txt
@echo %codenumber%03 *** Overall score: %engine_score%     Overall draw-rate: %engine_drawrate% >>worklist_losses.txt
@echo %codenumber%04 *** Average game length: All: %length_all% moves (wins: %length_wins% moves / draws: %length_draws% moves / losses: %length_loss% moves)>>worklist_losses.txt 
@echo %codenumber%05 *** Avg. eng play white: All: %length_all_w% moves (wins: %length_wins_w% moves / draws: %length_draws_w% moves / losses: %length_loss_w% moves)>>worklist_losses.txt 
@echo %codenumber%06 *** Avg. eng play black: All: %length_all_b% moves (wins: %length_wins_b% moves / draws: %length_draws_b% moves / losses: %length_loss_b% moves)>>worklist_losses.txt 
@echo %codenumber%07 ************************************************************************************************>>worklist_losses.txt
@echo %codenumber%08 *** all short losses loss0-30   loss31-35  loss36-40  loss41-45  loss46-50  loss51-55  loss56-60>>worklist_losses.txt
@echo %codenumber%09 *** -------------------------------------------------------------------------------------------->>worklist_losses.txt
@echo %codenumber%10 ***    [%percent_all_shortlosses%] =    [%list_losses_30mvs_pcnt%  +  %list_losses_35mvs_pcnt%  +  %list_losses_40mvs_pcnt%  +  %list_losses_45mvs_pcnt%  +  %list_losses_50mvs_pcnt%  +  %list_losses_55mvs_pcnt%  +  %list_losses_60mvs_pcnt%]>>worklist_losses.txt
@echo %codenumber%11 ***    [%list_all_losses%] =    [%list_losses_30mvs%  +  %list_losses_35mvs%  +  %list_losses_40mvs%  +  %list_losses_45mvs%  +  %list_losses_50mvs%  +  %list_losses_55mvs%  +  %list_losses_60mvs%]>>worklist_losses.txt
@echo %codenumber%12 ************************************************************************************************>>worklist_losses.txt
@echo %codenumber%13 XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX>>worklist_losses.txt

REM *** All engines done? then exit, otherwise jump back. Print estimated time needed until finishing ***
CALL :StopTimer2
CALL :EstimatedTime
@echo *********************************************************************************************

set /A engine_counter=%engine_counter%+1
if %engine_counter% GTR %numb_engines% goto exitloop02
goto loop02
:exitloop02


REM *** Add sac games to the final output pgn-file ***
pgn-extract --quiet -a../short_sac_games_no_endgame.pgn sacgames_queensacs.pgn >NUL
pgn-extract --quiet -a../short_sac_games_no_endgame.pgn sacgames_5_pawns.pgn >NUL
pgn-extract --quiet -a../short_sac_games_no_endgame.pgn sacgames_4_pawns.pgn >NUL
pgn-extract --quiet -a../short_sac_games_no_endgame.pgn sacgames_3_pawns.pgn >NUL
pgn-extract --quiet -a../short_sac_games_no_endgame.pgn sacgames_2_pawns.pgn >NUL
pgn-extract --quiet -a../short_sac_games_no_endgame.pgn sacgames_1_pawns.pgn >NUL

REM *** Delete all working files
del enginegames.pgn 2>nul
del newsource.pgn 2>nul
del whitewins.pgn 2>nul
del blackwins.pgn 2>nul
del allwins.pgn 2>nul
del whitelosses.pgn 2>nul
del blacklosses.pgn 2>nul
del alllosses.pgn 2>nul
del alldraws.pgn 2>nul
del no_endgame_games.pgn 2>nul
del results_opt1.pgn 2>nul
del results_opt2.pgn 2>nul 
del results_opt3.pgn 2>nul 
del results_opt4.pgn 2>nul 
del results_opt5.pgn 2>nul 
del results_opt9.pgn 2>nul 
del unique_opt1.pgn 2>nul 
del unique_opt2.pgn 2>nul 
del unique_opt3.pgn 2>nul 
del unique_opt4.pgn 2>nul 
del unique_opt5.pgn 2>nul 
del unique_opt9.pgn 2>nul 
del blacksacs.pgn 2>nul
del win60games.pgn 2>nul
del sacgames_1_pawns.pgn 2>nul
del sacgames_2_pawns.pgn 2>nul
del sacgames_3_pawns.pgn 2>nul
del sacgames_4_pawns.pgn 2>nul
del sacgames_5_pawns.pgn 2>nul
del sacgames_queensacs.pgn 2>nul
del white_eng_games.pgn 2>nul
del white_eng_games_wins.pgn 2>nul
del white_eng_games_draws.pgn 2>nul
del white_eng_games_losses.pgn 2>nul
del black_eng_games.pgn 2>nul
del black_eng_games_wins.pgn 2>nul
del black_eng_games_draws.pgn 2>nul
del black_eng_games_losses.pgn 2>nul


@echo *********************************************************************************************
@echo *** Building the final statistics-files... please wait...
@echo *********************************************************************************************

@echo ***************************************************************>../SGA_no_endgame_full_statistics.txt
@echo ***              Short Games Analyzer Tool V3.2             ***>>../SGA_no_endgame_full_statistics.txt
@echo ***           (C) 2022, Stefan Pohl, www.sp-cc.de           ***>>../SGA_no_endgame_full_statistics.txt
@echo ***************************************************************>>../SGA_no_endgame_full_statistics.txt
@echo *** Evaluated file: %gamebase% >>../SGA_no_endgame_full_statistics.txt
@echo *** Evaluated games: All ended before endgame was reached  >>../SGA_no_endgame_full_statistics.txt
@echo ***************************************************************>>../SGA_no_endgame_full_statistics.txt

REM *** Sort the output by codenumber ***
sort /r worklist.txt >>worklist2.txt
REM *** Delete codenumber and write final statistics-file line by line
set /A linecounter=0
set /A totallines=28*%numb_engines%
set /A tempcounter=0
:printloop01
del line.txt 2>nul
more +%linecounter% worklist2.txt>line.txt
set /A linecounter+=1
set /A tempcounter+=1
if %tempcounter% GTR 28 set /A tempcounter=1
set /p var=<line.txt
set var=%var:~11%
set /A rank=(%linecounter%/28)+1
if %tempcounter% EQU 2 set var=*** Rank %rank%: %var%
@echo %var%>>../SGA_no_endgame_full_statistics.txt
if %linecounter% LSS %totallines% goto printloop01


@echo ***************************************************************>../SGA_no_endgame_wins_statistics.txt
@echo ***              Short Games Analyzer Tool V3.2             ***>>../SGA_no_endgame_wins_statistics.txt
@echo ***           (C) 2022, Stefan Pohl, www.sp-cc.de           ***>>../SGA_no_endgame_wins_statistics.txt
@echo ***************************************************************>>../SGA_no_endgame_wins_statistics.txt
@echo *** Evaluated file: %gamebase% >>../SGA_no_endgame_wins_statistics.txt
@echo *** Evaluated games: All ended before endgame was reached  >>../SGA_no_endgame_wins_statistics.txt
@echo ***************************************************************>>../SGA_no_endgame_wins_statistics.txt

REM *** Sort the output by codenumber ***
sort /r worklist_wins.txt >>worklist2_wins.txt
REM *** Delete codenumber and write final statistics-file line by line
set /A linecounter=0
set /A totallines=18*%numb_engines%
set /A tempcounter=0
:printloop02
del line.txt 2>nul
more +%linecounter% worklist2_wins.txt>line.txt
set /A linecounter+=1
set /A tempcounter+=1
if %tempcounter% GTR 18 set /A tempcounter=1
set /p var=<line.txt
set var=%var:~11%
set /A rank=(%linecounter%/18)+1
if %tempcounter% EQU 2 set var=*** Rank %rank%: %var%
@echo %var%>>../SGA_no_endgame_wins_statistics.txt
if %linecounter% LSS %totallines% goto printloop02

@echo ***************************************************************>../SGA_no_endgame_draws_statistics.txt
@echo ***              Short Games Analyzer Tool V3.2             ***>>../SGA_no_endgame_draws_statistics.txt
@echo ***           (C) 2022, Stefan Pohl, www.sp-cc.de           ***>>../SGA_no_endgame_draws_statistics.txt
@echo ***************************************************************>>../SGA_no_endgame_draws_statistics.txt
@echo *** Evaluated file: %gamebase% >>../SGA_no_endgame_draws_statistics.txt
@echo *** Evaluated games: All ended before endgame was reached  >>../SGA_no_endgame_draws_statistics.txt
@echo ***************************************************************>>../SGA_no_endgame_draws_statistics.txt

REM *** Sort the output by codenumber ***
sort worklist_draws.txt >>worklist2_draws.txt
REM *** Delete codenumber and write final statistics-file line by line
set /A linecounter=0
set /A totallines=13*%numb_engines%
set /A tempcounter=0
:printloop03
del line.txt 2>nul
more +%linecounter% worklist2_draws.txt>line.txt
set /A linecounter+=1
set /A tempcounter+=1
if %tempcounter% GTR 13 set /A tempcounter=1
set /p var=<line.txt
set var=%var:~11%
set /A rank=(%linecounter%/13)+1
if %tempcounter% EQU 2 set var=*** Rank %rank%: %var%
@echo %var%>>../SGA_no_endgame_draws_statistics.txt
if %linecounter% LSS %totallines% goto printloop03


@echo ***************************************************************>../SGA_no_endgame_losses_statistics.txt
@echo ***              Short Games Analyzer Tool V3.2             ***>>../SGA_no_endgame_losses_statistics.txt
@echo ***           (C) 2022, Stefan Pohl, www.sp-cc.de           ***>>../SGA_no_endgame_losses_statistics.txt
@echo ***************************************************************>>../SGA_no_endgame_losses_statistics.txt
@echo *** Evaluated file: %gamebase% >>../SGA_no_endgame_losses_statistics.txt
@echo *** Evaluated games: All ended before endgame was reached  >>../SGA_no_endgame_losses_statistics.txt
@echo ***************************************************************>>../SGA_no_endgame_losses_statistics.txt

REM *** Sort the output by codenumber ***
sort worklist_losses.txt >>worklist2_losses.txt
REM *** Delete codenumber and write final statistics-file line by line
set /A linecounter=0
set /A totallines=13*%numb_engines%
set /A tempcounter=0
:printloop04
del line.txt 2>nul
more +%linecounter% worklist2_losses.txt>line.txt
set /A linecounter+=1
set /A tempcounter+=1
if %tempcounter% GTR 13 set /A tempcounter=1
set /p var=<line.txt
set var=%var:~11%
set /A rank=(%linecounter%/13)+1
if %tempcounter% EQU 2 set var=*** Rank %rank%: %var%
@echo %var%>>../SGA_no_endgame_losses_statistics.txt
if %linecounter% LSS %totallines% goto printloop04


del worklist.txt 2>nul
del worklist2.txt 2>nul
del worklist_wins.txt 2>nul
del worklist2_wins.txt 2>nul
del worklist_draws.txt 2>nul
del worklist2_draws.txt 2>nul
del worklist_losses.txt 2>nul
del worklist2_losses.txt 2>nul
del line.txt 2_nul
del results.pgn 2>nul

cd ../

@echo ****************
@echo *** Finished ***
@echo ****************
@echo *********************************************************************************************
@echo *** See complete results of the engines/players in the SGA_no_endgame_full_statistics.txt file
@echo *** See the results of the engines/player for wins/draws_losses in the files:
@echo *** SGA_no_endgame_wins_statistics.txt, SGA_no_endgame_draws_statistics.txt and 
@echo *** SGA_no_endgame_losses_statistics.txt
@echo *** All short games are stored in the file shortgames_no_endgame.pgn (wins followed by draws)
@echo *** All short win games with a sacrifice are stored in the file short_sac_games_no_endgame.pgn
@echo *** (sorted top-down: Highest sacs first, lowest behind...)
@echo *********************************************************************************************
CALL :StopTimer
CALL :DisplayTimerResult
@echo *********************************************************************************************
:error
CALL ./bin/playwav %windir%/media/alarm02.wav
pause
goto :EOF

:countgames
set /A c_numb_pgn=0
for /f "tokens=2,* delims= " %%G in ('find /C "[White " %~1') do set /A c_numb_pgn=%%H
exit /B 0

:percent
if %~1 LEQ 0 (
set percent=00.00%%
set /A percentx100=0
EXIT /B 0
)
set /A l_base=((1000000000/%~1)*%~2)
set /A l_percent=%l_base%/1000000
set /A l_rest1=%l_percent%%%10
set /A l_percent=%l_percent%/10
set /A l_secdig_pc=%l_base%/100000
set /A l_rest2=%l_secdig_pc%%%10
set /A l_thirddig_pc=%l_base%/10000
set /A l_rest3=%l_thirddig_pc%%%10

REM *** Round 2nd digit up, if 3rd digit is GEQ 5 and round 1st digit and percent-value up, if necessary
if %l_rest3% GEQ 5 set /A l_rest2+=1
if %l_rest2% GEQ 10 (
  set /A l_rest2-=10
  set /A l_rest1+=1
)
if %l_rest1% GEQ 10 (
  set /A l_rest1-=10
  set /A l_percent+=1
)

if %l_percent% LSS 10 (
  set percent=0%l_percent%.%l_rest1%%l_rest2%%%
) else (
  set percent=%l_percent%.%l_rest1%%l_rest2%%%
)
set /A percentx100=(%l_percent%*100)+(%l_rest1%*10)+%l_rest2%

if %l_percent% GTR 99 (
set percent=100.0%%
set /A percentx100=10000
)
EXIT /B 0

:moveaverage
set ma_gamefile=%~1
CALL :countgames %ma_gamefile%
if %c_numb_pgn% LEQ 0 (
set /A ma_moveaverage=0
EXIT /B 0
)
summary.exe %ma_gamefile% >NUL
for /f "tokens=1-10 delims=., " %%A in ('find "Average" outSummary') do ( 
set ma_avg=%%I >NUL
set ma_rest=%%J > NUL
)
set ma_avg=%ma_avg:~0,-1%
set ma_rest=%ma_rest:~0,-1%
REM *** Round ply-moveaverage up, if necessary
if %ma_rest% GEQ 50 set /A ma_avg+=1
set /A ma_moveaverage=%ma_avg%/2
del outSummary 2>nul
EXIT /B 0

:formatnumb
set /A fn_numb=%~1
if %fn_numb% LEQ 9 (
set formatted=     %fn_numb%
goto exitformatnumb)
if %fn_numb% LEQ 99 (
set formatted=    %fn_numb%
goto exitformatnumb)
if %fn_numb% LEQ 999 (
set formatted=   %fn_numb%
goto exitformatnumb)
if %fn_numb% LEQ 9999 (
set formatted=  %fn_numb%
goto exitformatnumb)
if %fn_numb% LEQ 99999 (
set formatted= %fn_numb%
goto exitformatnumb)
if %fn_numb% LEQ 999999 (
set formatted=%fn_numb%
goto exitformatnumb)
:exitformatnumb
EXIT /B 0

:StartTimer
set StartTIME=%TIME%
for /f "usebackq tokens=1-4 delims=:., " %%f in (`echo %StartTIME: =0%`) do set /a Start100S=1%%f*360000+1%%g*6000+1%%h*100+1%%i-36610100
EXIT /B 0

:StopTimer
set StopTIME=%TIME%
for /f "usebackq tokens=1-4 delims=:., " %%f in (`echo %StopTIME: =0%`) do set /a Stop100S=1%%f*360000+1%%g*6000+1%%h*100+1%%i-36610100
if %Stop100S% LSS %Start100S% set /a Stop100S+=8640000
set /a TookTime=%Stop100S%-%Start100S%
set TookTimePadded=0%TookTime%
EXIT /B 0

:StartTimer2
set StartTIME2=%TIME%
for /f "usebackq tokens=1-4 delims=:., " %%f in (`echo %StartTIME2: =0%`) do set /a Start100S2=1%%f*360000+1%%g*6000+1%%h*100+1%%i-36610100
EXIT /B 0

:StopTimer2
set StopTIME2=%TIME%
for /f "usebackq tokens=1-4 delims=:., " %%f in (`echo %StopTIME2: =0%`) do set /a Stop100S2=1%%f*360000+1%%g*6000+1%%h*100+1%%i-36610100
if %Stop100S2% LSS %Start100S2% set /a Stop100S2+=8640000
set /a TookTime2=%Stop100S2%-%Start100S2%
set TookTimePadded2=0%TookTime2%
EXIT /B 0

:DisplayTimerResult
set /A t_elapsed=%TookTime:~0,-2%.%TookTimePadded:~-2% 2>nul
set /A t_seconds=%t_elapsed%
set /A t_minutes=%t_seconds%/60
set /A t_hours=%t_minutes%/60
set /A t_seconds-=%t_minutes%*60
set /A t_minutes-=%t_hours%*60
if %t_seconds% LEQ 9 set t_seconds=0%t_seconds%
if %t_minutes% LEQ 9 set t_minutes=0%t_minutes%
if %t_hours% LEQ 9 set t_hours=0%t_hours%
@echo *** Elapsed time: %t_hours%:%t_minutes%:%t_seconds%
EXIT /B 0

:EstimatedTime
set /A t_elapsed=%TookTime2:~0,-2%.%TookTimePadded2:~-2% 2>nul
set /A t_time_per_engine=%t_elapsed%/%engine_counter
set /A t_engines_to_do=%numb_engines%-%engine_counter%
set /A t_estimated=(%t_engines_to_do%*%t_time_per_engine%)+(%numb_engines%*2)
set /A t_seconds=%t_estimated%
set /A t_minutes=%t_seconds%/60
set /A t_hours=%t_minutes%/60
set /A t_seconds-=%t_minutes%*60
set /A t_minutes-=%t_hours%*60
if %t_seconds% LEQ 9 set t_seconds=0%t_seconds%
if %t_minutes% LEQ 9 set t_minutes=0%t_minutes%
if %t_hours% LEQ 9 set t_hours=0%t_hours%
@echo *** Estimated time until finishing: %t_hours%:%t_minutes%:%t_seconds%
EXIT /B 0




